# DE_LogEventos
Pacote de funcionalidades para geração de Log de monitoramento de processos
#### Dependencias
Python: 3.9 (recomendado) [python.org](https://www.python.org/)
setutools, wheel e twine [PyPI](https://pypi.org)
```
pip install setuptools
pip install wheel
pip install twine
```
#### Instalação
Para clonar este repositorio em sua maquina local use:
```
git clone https://github.com/almirjgomes/DE_LogEventos.git
- License MIT
```